/*---[ menus.h ]------------------------------------------------------
 * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Functions for installing menus, toolbars and popups
 *--------------------------------------------------------------------*/

#ifndef _FIRESTARTER_MENUS
#define _FIRESTARTER_MENUS

#include <config.h>
#include <gnome.h>

GtkWidget *appbar;


void install_menus_and_toolbar (GtkWidget *app);
void hitview_popup_menu (GdkEventButton *bevent);
void install_clist_popup (GtkWidget *clist);
void install_docklet_menu (GtkWidget *eventbox);

void ruleview_popup_menu (GdkEventButton *bevent);

#endif
